==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/PinnedAreaSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { PinnedAreaSeparatorDescription } from "./PinnedAreaSeparatorDescription";
/**
 * @hidden
 */
export let PinnedAreaSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class PinnedAreaSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (PinnedAreaSeparatorDescriptionMetadata.a == null) {
                PinnedAreaSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PinnedAreaSeparatorDescriptionMetadata.c(PinnedAreaSeparatorDescriptionMetadata.a);
            }
            if (a.k(PinnedAreaSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(PinnedAreaSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            PinnedAreaSeparatorDescriptionMetadata.b(a);
            a.ad("PinnedAreaSeparator", () => new PinnedAreaSeparatorDescription());
            a.ac("PinnedAreaSeparator", PinnedAreaSeparatorDescriptionMetadata.a);
        }
    }
    PinnedAreaSeparatorDescriptionMetadata.$t = /*@__PURE__*/ markType(PinnedAreaSeparatorDescriptionMetadata, 'PinnedAreaSeparatorDescriptionMetadata');
    PinnedAreaSeparatorDescriptionMetadata.a = null;
    return PinnedAreaSeparatorDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/PinnedAreaSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { PinnedAreaSeparatorDescription } from "./PinnedAreaSeparatorDescription";
/**
 * @hidden
 */
export let PinnedAreaSeparatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class PinnedAreaSeparatorDescriptionMetadata extends Base {
        static b(a) {
            if (PinnedAreaSeparatorDescriptionMetadata.a == null) {
                PinnedAreaSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PinnedAreaSeparatorDescriptionMetadata.c(PinnedAreaSeparatorDescriptionMetadata.a);
            }
            if (a.k(PinnedAreaSeparatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(PinnedAreaSeparatorDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            PinnedAreaSeparatorDescriptionMetadata.b(a);
            a.ae("PinnedAreaSeparator", () => new PinnedAreaSeparatorDescription());
            a.ad("PinnedAreaSeparator", PinnedAreaSeparatorDescriptionMetadata.a);
        }
    }
    PinnedAreaSeparatorDescriptionMetadata.$t = /*@__PURE__*/ markType(PinnedAreaSeparatorDescriptionMetadata, 'PinnedAreaSeparatorDescriptionMetadata');
    PinnedAreaSeparatorDescriptionMetadata.a = null;
    return PinnedAreaSeparatorDescriptionMetadata;
})();
